#
# spec file for package WoeUSB
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           WoeUSB
Version:        5.2.4
Release:        1.11
Summary:        Windows USB installation media creator
License:        GPL-3.0-or-later
URL:            https://github.com/WoeUSB/WoeUSB
Source:         https://github.com/WoeUSB/WoeUSB/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  libtool
Requires:       bash >= 4.3
Requires:       dosfstools
Requires:       findutils
Requires:       gawk
Requires:       grep
Requires:       grub2
Requires:       ntfsprogs
Requires:       parted
Requires:       util-linux
Requires:       wget
Requires:       wimtools
Recommends:     p7zip
BuildArch:      noarch

%description
WoeUSB is a utility for creating a bootable Windows installation
USB storage device from an existing Windows installation disc or disk image.

%prep
%setup -q
%autosetup
find . -type f -exec sed -i "s/@@WOEUSB_VERSION@@/%{version}/" {} \+
sed -i '1 s/env //' sbin/woeusb

%build

%install
install -Dm 755 sbin/woeusb %{buildroot}%{_sbindir}/woeusb
install -Dm 644 share/man/man1/woeusb.1 %{buildroot}%{_mandir}/man1/woeusb.1
install -Dm 644 share/woeusb/woeusb.svg %{buildroot}%{_datadir}/woeusb/woeusb.svg
%fdupes %{buildroot}

%files
%doc README.md
%license LICENSES/
%{_sbindir}/woeusb
%{_mandir}/man1/woeusb.1%{?ext_man}
%dir %{_datadir}/woeusb
%{_datadir}/woeusb/woeusb.svg

%changelog
* Mon Nov 29 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 5.2.4:
  - no changelog available
  - completely rewritten
  now only a bash script
* Mon Feb 10 2020 Yunhe Guo <i@guoyunhe.me>
- Version 3.3.1
  * Fixed echo write error on Linux kernel 5.4
  * Other minor bug fixes
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Apr 21 2019 Yunhe Guo <i@guoyunhe.me>
- Version 3.3.0
  * Improvements to the WoeUSB GUI
  * The option of using the NTFS filesystem as the target filesystem
    has now being provided in the GUI
* Sun Mar 31 2019 Aleksa Sarai <asarai@suse.com>
- Explicitly Require all runtime dependencies, rather than depending on users
  to install packages from the startup error messages.
* Tue Dec 25 2018 Yunhe Guo <i@guoyunhe.me>
- Version 3.2.12
  * This release features some minor improvements to the code.
- Version 3.2.11
  * This release fixes a big regression causing source image with
    >4GiB file can't be installed on disks with NTFS target filesystem
    using --partition USB preparation mode, refer Issue #226 for more
    info.
  * We would like to thank Luke Anderson(@spble) that brought up the
    issue, @0xC1A551C for confirming it and providing mitigation,
    and everyone in the discussion thread that helped to escalate
    the issue.
* Wed Sep 19 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.10
  * This release fixes a regression that makes the --partition
    device preparation mode failed to work. We would like to thank
    @jackvnimble for the patch!
* Sun Sep 16 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.9
  * This release fixes a regression that will make --target-filesystem
    command-line option not working(#210).  We would like to thank
    @mishka81 for bringing up the issue.
- Version 3.2.8
  * This release fixes a typecasting bug in the graphical wrapper
    code. We would like to thank @dcb314 and @Skrilltrax for bringing
    it up and provide the patch!
- Version 3.2.7
  * This release fixes a typo which will lead to command not found
    when FAT32 4GiB single file size limitation is detected. Enjoy!
- Version 3.2.6
  * This release fixes a issue when user uses lowercase filesystem
    name as --target-filesystem's argument.
- Version 3.2.5
  * This release fixes a major regression introduced by v3.2.4.
* Thu Sep 13 2018 Yunhe Guo <yunhe.guo@protonmail.com>
- Version 3.2.4
  * This release features a major cleanup to the code, be sure to
    report any regressions you've encountered.
- Version 3.2.3
  * This release fixes a bug that will make woeusb bailout when the
    ISO filename contains a valid token of a regular expression.
* Tue Aug 14 2018 guoyunhebrave@gmail.com
- Version 3.2.2
  * This release improves compatibility with space-included filenames.
* Wed May  9 2018 guoyunhebrave@gmail.com
- Version 3.2.1
  * This patch release fixes the fatal error slipped into last minute patch in v3.2.0.
* Tue May  8 2018 guoyunhebrave@gmail.com
- Version 3.2.0
  * A check for "FAT32 Filesystem 4GiB Single File Size Limitation" has been
    implemented thanks to Jakub Szymański
  * A fix to comply with the recent changes of UEFI:NTFS has been implemented
    thanks to Felipe Magno de Almeida
  * PNG images distributed in WoeUSB has been optimized to smaller size thanks
    to Peter Dave Hello
  * A typo has been picked out in woeusb(1) manpage thanks to Anthony Fok
  * Detailed changes see https://github.com/slacka/WoeUSB/releases/tag/v3.2.0
* Thu Mar 29 2018 guoyunhebrave@gmail.com
- Version 3.1.5
  * Packaging: Debian: Downgrade debian/compat to 9 to match debian/control
  * Packaging: Debian: Downgrade debhelper dependency to v9 to support Ubuntu 14.04(till April 2019)
  * Packaging: Debian: Add missing build dependency: dh-autoreconf
  * Packaging: Debian: Depend on grub2-common instead of grub-common
  * Packaging: Debian: Add gettext package as build dependencies
  * Merge branch 'master' of github.com:slacka/WoeUSB
  * Manpages: woeusbgui(1): Fix typo
  * Add VCS- fields to debian/control
  * Remove versioned dependencies where satisfied by all releases since oldoldstable (Wheezy)
  * Remove dependencies on essential packages as they're always there
  * Fix priority-extra-is-replaced-by-priority-optional
  * Bump Debian Standards Version to 4.1.1
  * build-depends-on-1-revision build-depends: coreutils (>= 8.23-1)
  * Remove trailing whitespace
  * Fix obsolete-relation-form-in-source in woeusb depends: bash (>4.3)
  * core: Eliminate abused double quotes
* Sat Mar 10 2018 sebix+novell.com@sebix.at
- update to version 3.1.4:
  * no changelog available, please see https://github.com/slacka/WoeUSB/commits/master
* Mon Jan 15 2018 jengelh@inai.de
- Avoid assuming specific user context in description.
* Fri Dec 22 2017 sebix+novell.com@sebix.at
- inital package for version 2.2.2
